==> traintrain_0.1.1-1.tar.gz: traintrain-0.1.1/src/opt/traintrain/model/TrainTrainModel.py <==
﻿#!/usr/bin/python
# -*- coding: utf-8 -*-

import re, time, os
from PyQt4 import QtCore, QtGui
from PyQt4.QtCore import QAbstractTableModel, Qt, QVariant
from DebugLog import DebugLog
from TrainDb import  DbTrain, GareManager
import ConfigParser
from ConfFile import ConfFile, RidesConfig
from ExtractorTransilien import ExtractorTransilien
from ExtractorMetroMobi import ExtractorMetro
from ExtractorRERratp import ExtractorRERratp

class CellModel:
   def __init__(self):
      self.data = dict()
      self.data[Qt.FontRole] = QVariant()
      self.data[Qt.DisplayRole] = ''
      self.data[Qt.DecorationRole] = QVariant()
      self.data[Qt.BackgroundRole] = QVariant()
      self.data[Qt.ForegroundRole] = QVariant()
      self.data[Qt.TextAlignmentRole] = QVariant( Qt.AlignCenter|Qt.AlignVCenter )

   def __getitem__(self, item):
      try:
         return self.data[item]
      except KeyError:
         return QVariant()

   def __setitem__(self, item, val):
      self.data[item] = val

class TrainTrainModel(QAbstractTableModel):
   def __init__(self):
      QAbstractTableModel.__init__(self)
      DebugLog("TrainTrainModel::Init")

      self.labels = ['Train', 'Heure', 'Destination', 'Voie']

      confDir = os.path.join(os.path.expanduser('~'),".traintrain")
      if not os.path.exists(confDir):
         os.makedirs(confDir)

      self.confFile = os.path.join(confDir, "traintrain.conf")
      self.ridesConfFile = os.path.join(confDir, "trajets.conf")

      self.garesConf = RidesConfig(self.ridesConfFile)
      self.arraydata = []
      self.rides = dict()
      self.db = DbTrain()
      self.gareMgr = GareManager(self.db)
      self.online = True
      self.max = 2

   def GetRidesModel(self):
      return [self.rides[k] for k in sorted(self.rides.keys())]

   def AddRideModel(self, ridemodel):
      DebugLog("TrainTrainModel::AddRideModel")
      self.rides[ridemodel.id] = ridemodel

   def RemoveRideModel(self, rideModel):
      self.garesConf.RemoveRide(rideModel.id)
      del self.rides[rideModel.id]

   def InsertWarnings(self, rows):
      DebugLog("TrainTrainModel::InsertWarning")

      self.insertRows(0, len(rows), QtCore.QModelIndex)
      rowPos=0
      for row in rows:
         index = self.createIndex(rowPos, 0, QtCore.QModelIndex)
         self.setData(index, row[0], Qt.DisplayRole)
         rowPos += 1

      self.emit(QtCore.SIGNAL("dataChanged(index, index)"))

   def SetOnline(self, b):
      self.online = b

   def CreateAndAddRide(self, ligne):
      if ligne.tec=='RER' and ligne.exploitant=='S':
         extractor = ExtractorTransilien(ligne)

      elif ligne.tec == 'Metro':
         extractor = ExtractorMetro(ligne)

      elif ligne.tec == 'RER' and ligne.exploitant=='R': # RATP
         extractor = ExtractorRERratp(ligne)

      if extractor:
         self.rideList.append(extractor)
         self.AddRideModel( extractor.rideModel )
         self.connect(extractor, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
         extractor.SetOnline(self.online)
         extractor.FetchDatas(self, self.max)
         return extractor.rideModel
      else:
         return None

   def InitDatas(self):
      DebugLog("TrainTrainModel::InitDatas")

      self.garesConf.ReadRides()
      self.rideList = []
      self.arraydata = []
      self.reset()

      for ligne in self.garesConf.GetRides():
         self.CreateAndAddRide(ligne)

   def Extracted(self, rideModel):
      self.emit(QtCore.SIGNAL('extracted'), rideModel)

   def RefreshDatas(self):
      DebugLog("TrainTrainModel::RefreshDatas")
      for extractor in self.rideList:
         extractor.FetchDatas(self, self.max)

==> traintrain_0.1.2-1.tar.gz: traintrain-0.1.2/src/opt/traintrain/model/TrainTrainModel.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

import re, time, os
from PyQt4 import QtCore, QtGui
from PyQt4.QtCore import QAbstractTableModel, Qt, QVariant
from utils.DebugLog import DebugLog
from utils.TrainDb import  DbTrain, GareManager
import ConfigParser
from utils.ConfFile import ConfFile, RidesConfig
from extractors.ExtractorTransilien import ExtractorTransilien
from extractors.ExtractorMetroMobi import ExtractorMetro
from extractors.ExtractorRERratp import ExtractorRERratp

class CellModel:
   def __init__(self):
      self.data = dict()
      self.data[Qt.FontRole] = QVariant()
      self.data[Qt.DisplayRole] = ''
      self.data[Qt.DecorationRole] = QVariant()
      self.data[Qt.BackgroundRole] = QVariant()
      self.data[Qt.ForegroundRole] = QVariant()
      self.data[Qt.TextAlignmentRole] = QVariant( Qt.AlignCenter|Qt.AlignVCenter )

   def __getitem__(self, item):
      try:
         return self.data[item]
      except KeyError:
         return QVariant()

   def __setitem__(self, item, val):
      self.data[item] = val

class TrainTrainModel(QAbstractTableModel):
   def __init__(self):
      QAbstractTableModel.__init__(self)
      DebugLog("TrainTrainModel::Init")

      self.labels = ['Train', 'Heure', 'Destination', 'Voie']

      confDir = os.path.join(os.path.expanduser('~'),".traintrain")
      if not os.path.exists(confDir):
         os.makedirs(confDir)

      self.confFile = os.path.join(confDir, "traintrain.conf")
      self.ridesConfFile = os.path.join(confDir, "trajets.conf")

      self.garesConf = RidesConfig(self.ridesConfFile)
      self.arraydata = []
      self.rides = dict()
      self.db = DbTrain()
      self.gareMgr = GareManager(self.db)
      self.online = True
      self.max = 2

   def GetRidesModel(self):
      return [self.rides[k] for k in sorted(self.rides.keys())]

   def AddRideModel(self, ridemodel):
      DebugLog("TrainTrainModel::AddRideModel")
      self.rides[ridemodel.id] = ridemodel

   def RemoveRideModel(self, rideModel):
      self.garesConf.RemoveRide(rideModel.id)
      del self.rides[rideModel.id]

   def InsertWarnings(self, rows):
      DebugLog("TrainTrainModel::InsertWarning")

      self.insertRows(0, len(rows), QtCore.QModelIndex)
      rowPos=0
      for row in rows:
         index = self.createIndex(rowPos, 0, QtCore.QModelIndex)
         self.setData(index, row[0], Qt.DisplayRole)
         rowPos += 1

      self.emit(QtCore.SIGNAL("dataChanged(index, index)"))

   def SetOnline(self, b):
      self.online = b

   def CreateAndAddRide(self, ligne):
      if ligne.tec=='RER' and ligne.exploitant=='S':
         extractor = ExtractorTransilien(ligne)

      elif ligne.tec == 'Metro':
         extractor = ExtractorMetro(ligne)

      elif ligne.tec == 'RER' and ligne.exploitant=='R': # RATP
         extractor = ExtractorRERratp(ligne)

      if extractor:
         self.rideList.append(extractor)
         self.AddRideModel( extractor.rideModel )
         self.connect(extractor, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
         extractor.SetOnline(self.online)
         extractor.FetchDatas(self, self.max)
         return extractor.rideModel
      else:
         return None

   def InitDatas(self):
      DebugLog("TrainTrainModel::InitDatas")

      self.garesConf.ReadRides()
      self.rideList = []
      self.arraydata = []
      self.reset()

      for ligne in self.garesConf.GetRides():
         self.CreateAndAddRide(ligne)

   def Extracted(self, rideModel):
      self.emit(QtCore.SIGNAL('extracted'), rideModel)

   def RefreshDatas(self):
      DebugLog("TrainTrainModel::RefreshDatas")
      for extractor in self.rideList:
         extractor.FetchDatas(self, self.max)
